Index: /issm/trunk-jpl/scripts/GenerateReferences.sh
===================================================================
--- /issm/trunk-jpl/scripts/GenerateReferences.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/GenerateReferences.sh	(revision 12159)
@@ -16,5 +16,5 @@
 \begin{document}
 \nocite{$CITE}
-\bibliography{$ISSM_DIR/publications/bibtex/references}
+\bibliography{$JPL_SVN/publications/bibtex/references}
 \end{document}
 END
@@ -29,5 +29,5 @@
 mv references.bak2 references.bbl
 echo "Converting to rtf"
-$ISSM_TIER/externalpackages/latex2rtf/install/latex2rtf -P $ISSM_TIER/externalpackages/latex2rtf/install/cfg/ references
+$ISSM_DIR/externalpackages/latex2rtf/install/latex2rtf -P $ISSM_DIR/externalpackages/latex2rtf/install/cfg/ references
 
 #Remove all but rtf file
Index: /issm/trunk-jpl/scripts/archive.sh
===================================================================
--- /issm/trunk-jpl/scripts/archive.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/archive.sh	(revision 12159)
@@ -10,5 +10,5 @@
 
 #Cleanup code 
-cd $ISSM_TIER
+cd $ISSM_DIR
 make clean
 make distclean
@@ -18,5 +18,5 @@
 
 #Create tar file, with today's date in the title;
-cd $ISSM_TIER/..
+cd $ISSM_DIR/..
 today=`today_date`
-tar zcvf issm-3.0-$today.tar.gz  `basename $ISSM_TIER`
+tar zcvf issm-3.0-$today.tar.gz  `basename $ISSM_DIR`
Index: /issm/trunk-jpl/scripts/automakererun.sh
===================================================================
--- /issm/trunk-jpl/scripts/automakererun.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/automakererun.sh	(revision 12159)
@@ -4,8 +4,8 @@
 
 
- ACLOCAL="$ISSM_TIER/externalpackages/automake/install/bin/aclocal"
-AUTOCONF="$ISSM_TIER/externalpackages/autoconf/install/bin/autoconf"
-AUTOHEAD="$ISSM_TIER/externalpackages/autoconf/install/bin/autoheader"
-AUTOMAKE="$ISSM_TIER/externalpackages/automake/install/bin/automake"
+ ACLOCAL="$ISSM_DIR/externalpackages/automake/install/bin/aclocal"
+AUTOCONF="$ISSM_DIR/externalpackages/autoconf/install/bin/autoconf"
+AUTOHEAD="$ISSM_DIR/externalpackages/autoconf/install/bin/autoheader"
+AUTOMAKE="$ISSM_DIR/externalpackages/automake/install/bin/automake"
 
 echo "removing config.cach"
Index: /issm/trunk-jpl/scripts/cloc2html.py
===================================================================
--- /issm/trunk-jpl/scripts/cloc2html.py	(revision 12158)
+++ /issm/trunk-jpl/scripts/cloc2html.py	(revision 12159)
@@ -4,6 +4,6 @@
 import sys, re, os
 
-ISSM_TIER=os.getenv('ISSM_TIER');
-if(not ISSM_TIER): raise NameError('ISSM_TIER undefined')
+ISSM_DIR=os.getenv('ISSM_DIR');
+if(not ISSM_DIR): raise NameError('ISSM_DIR undefined')
 
 infile  = open('temp','r')
Index: /issm/trunk-jpl/scripts/convertmatlabclasses.py
===================================================================
--- /issm/trunk-jpl/scripts/convertmatlabclasses.py	(revision 12158)
+++ /issm/trunk-jpl/scripts/convertmatlabclasses.py	(revision 12159)
@@ -4,8 +4,8 @@
 
 #get names of all directories to process
-ISSM_TIER=os.getenv('ISSM_TIER');
-if(not ISSM_TIER): raise NameError('ISSM_TIER undefined')
-newclassesdir = ISSM_TIER + '/src/m/classes/'
-oldclassesdir = ISSM_TIER + '/src/m/oldclasses/'
+ISSM_DIR=os.getenv('ISSM_DIR');
+if(not ISSM_DIR): raise NameError('ISSM_DIR undefined')
+newclassesdir = ISSM_DIR + '/src/m/classes/'
+oldclassesdir = ISSM_DIR + '/src/m/oldclasses/'
 
 #make new directory
Index: /issm/trunk-jpl/scripts/getloc.sh
===================================================================
--- /issm/trunk-jpl/scripts/getloc.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/getloc.sh	(revision 12159)
@@ -1,12 +1,12 @@
 #!/bin/bash
 #get number of lines of code
-cloc-1.55.pl $ISSM_TIER/src $ISSM_TIER/m4 --exclude-dir=.svn --exclude-ext=exp --exclude-lang=make --out=temp
+cloc-1.55.pl $ISSM_DIR/src $ISSM_DIR/m4 --exclude-dir=.svn --exclude-ext=exp --exclude-lang=make --out=temp
 cat temp
 ./cloc2html.py
 rm temp
 
-cat $ISSM_TIER/src/dox/issm.dox | sed '/<table/,//d' > input1
-cat $ISSM_TIER/src/dox/issm.dox | sed '1,/<\/table>/d' > input2
-cat input1 temp.html input2 > $ISSM_TIER/src/dox/issm.dox
+cat $ISSM_DIR/src/dox/issm.dox | sed '/<table/,//d' > input1
+cat $ISSM_DIR/src/dox/issm.dox | sed '1,/<\/table>/d' > input2
+cat input1 temp.html input2 > $ISSM_DIR/src/dox/issm.dox
 rm input1 input2 temp.html
 
@@ -19,10 +19,10 @@
 #OLDER MANUAL VESION
 #get Matlab number of lines
-cd $ISSM_TIER/src/m
+cd $ISSM_DIR/src/m
 M_LOC=$(find . -name "*.m" -exec wc -l '{}' \; | awk '{ sum += $1 } END { print sum}');
 echo "Matlab code: $M_LOC"
 
 #get C/CPP number of lines
-cd $ISSM_TIER/src
+cd $ISSM_DIR/src
 CPP_LOC=$(find . -name "*.cpp" -exec wc -l '{}' \; | awk '{ sum += $1 } END { print sum}');
 echo "C++    code: $CPP_LOC"
Index: /issm/trunk-jpl/scripts/issmconfiguration.sh
===================================================================
--- /issm/trunk-jpl/scripts/issmconfiguration.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/issmconfiguration.sh	(revision 12159)
@@ -7,6 +7,6 @@
 presendir=`pwd`
 
-if test -d "$ISSM_TIER/configs" ; then
-	cd $ISSM_TIER/configs
+if test -d "$ISSM_DIR/configs" ; then
+	cd $ISSM_DIR/configs
 	LIST=`ls`
 	
@@ -40,5 +40,5 @@
 	echo ""
 
-	cd $ISSM_TIER 
+	cd $ISSM_DIR 
 	source ./scripts/automakererun.sh 
 	source configs/$configurename
@@ -56,3 +56,3 @@
 
 
-#alias aut='a=`pwd` && cd $ISSM_TIER && ./scripts/automakererun.sh && ./configs/config-macosx64-larour-nopetsc.sh'
+#alias aut='a=`pwd` && cd $ISSM_DIR && ./scripts/automakererun.sh && ./configs/config-macosx64-larour-nopetsc.sh'
Index: /issm/trunk-jpl/scripts/report.sh
===================================================================
--- /issm/trunk-jpl/scripts/report.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/report.sh	(revision 12159)
@@ -49,5 +49,5 @@
 
 #create some variables
-if [ $(ls -1 $ISSM_TIER/bin | wc -l) -le 20 ];
+if [ $(ls -1 $ISSM_DIR/bin | wc -l) -le 20 ];
 then
 	IS_INSTALL=0
Index: /issm/trunk-jpl/scripts/run.sh
===================================================================
--- /issm/trunk-jpl/scripts/run.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/run.sh	(revision 12159)
@@ -6,6 +6,6 @@
 MATLAB_VERSION="7.6" #7.2,7.4,7.6 and 7.8
 #create softlink to startup {{{1
-cd $ISSM_TIER/test/NightlyRun/
-ln -s $ISSM_TIER/startup.m .
+cd $ISSM_DIR/test/NightlyRun/
+ln -s $ISSM_DIR/startup.m .
 #}}}
 
@@ -14,8 +14,8 @@
 do
 	#Launch matlab and the daily run script
-	cat > $ISSM_TIER/dailylog/matlab_run$i.m << EOF
+	cat > $ISSM_DIR/dailylog/matlab_run$i.m << EOF
 	warning off %necessary to avoid a daily.log of several Go for parallel runs
 	try,
-		cd $ISSM_TIER/test/NightlyRun
+		cd $ISSM_DIR/test/NightlyRun
 		startup;
 		$(if [ "$NROPTIONS" = ""  ]
@@ -30,5 +30,5 @@
 		directory=strsplit(pwd,'/');
 		message=getReport(me)
-		fid=fopen([ISSM_TIER '/dailylog/matlaberror.log'], 'at');
+		fid=fopen([ISSM_DIR '/dailylog/matlaberror.log'], 'at');
 		fprintf(fid,'\nMatlab error occured in: %s\n\n',directory{end});
 		fprintf(fid,'%s',message);
@@ -39,5 +39,5 @@
 
 	#Start run from dailylog directory
-	cd $ISSM_TIER/dailylog/
+	cd $ISSM_DIR/dailylog/
 
 	#Start test
Index: /issm/trunk-jpl/scripts/windowsbuild.sh
===================================================================
--- /issm/trunk-jpl/scripts/windowsbuild.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/windowsbuild.sh	(revision 12159)
@@ -11,5 +11,5 @@
 today=`today_date`
 
-cd $ISSM_TIER/bin
+cd $ISSM_DIR/bin
 
 #Filter out .svn files

Index: /issm/trunk-jpl/scripts/dailyrun.sh
===================================================================
--- /issm/trunk-jpl/scripts/dailyrun.sh	(revision 12158)
+++ /issm/trunk-jpl/scripts/dailyrun.sh	(revision 12159)
@@ -54,15 +54,15 @@
 #Prepare run
 #Windows hack for startup.m {{{1
 #windows environments: ISSM_TIER_WIN variable not correctly picked up when using 
 #the cron job. just get startup to take the ISSM_TIER variable as the pwd:
 if [ "$OS" = "winxp32" ]
 then
-	cat startup.m | sed 's/clear status/clear status; ISSM_TIER=pwd;/g' > startup.m.bak
+	cat startup.m | sed 's/clear status/clear status; ISSM_DIR=pwd;/g' > startup.m.bak
 	mv startup.m.bak startup.m
 fi
 #}}}
 #create softlink to startup {{{1
-cd $ISSM_TIER/test/NightlyRun/
-ln -s $ISSM_TIER/startup.m .
+cd $ISSM_DIR/test/NightlyRun/
+ln -s $ISSM_DIR/startup.m .
 #}}}
 #Create dailylog directory and info.log {{{1
@@ -70,7 +70,7 @@
 INSTALL_TIME=$(timer)
 ELAPSED_INSTALL=$(timer $START_TIME)
-rm -rf $ISSM_TIER/dailylog
-mkdir  $ISSM_TIER/dailylog
-cat << END > $ISSM_TIER/dailylog/info.log
+rm -rf $ISSM_DIR/dailylog
+mkdir  $ISSM_DIR/dailylog
+cat << END > $ISSM_DIR/dailylog/info.log
 today:     $(echo $TODAY)
 user:      $(echo $USER)
@@ -95,8 +95,8 @@
 do
 	#Launch matlab and the daily run script
-	cat > $ISSM_TIER/dailylog/matlab_run$i.m << EOF
+	cat > $ISSM_DIR/dailylog/matlab_run$i.m << EOF
 	warning off %necessary to avoid a info.log of several Go for parallel runs
 	try,
-	cd $ISSM_TIER/test/NightlyRun
+	cd $ISSM_DIR/test/NightlyRun
 	startup;
 	$(if [ "$NROPTIONS" = ""  ]
@@ -111,5 +111,5 @@
 		directory=strsplit(pwd,'/');
 		message=getReport(me)
-		fid=fopen([ISSM_TIER '/dailylog/matlaberror.log'], 'at');
+		fid=fopen([ISSM_DIR '/dailylog/matlaberror.log'], 'at');
 		fprintf(fid,'\nMatlab error occured in: %s\n\n',directory{end});
 		fprintf(fid,'%s',message);
@@ -121,5 +121,5 @@
 
 	#Start run from dailylog directory
-	cd $ISSM_TIER/dailylog/
+	cd $ISSM_DIR/dailylog/
 
 	#Start test
@@ -132,5 +132,5 @@
 #}}}
 #concatenate all reports {{{1
-cd $ISSM_TIER/dailylog/
+cd $ISSM_DIR/dailylog/
 mv matlab_log1.log  matlab_log.log
 for (( i=2;i<=$NUMCPUS_RUN;i++ ))
@@ -149,5 +149,5 @@
 ELAPSED_RUN=$(timer $INSTALL_TIME)
 ELAPSED_TOTAL=$(timer $START_TIME)
-cat << END >>  $ISSM_TIER/dailylog/info.log
+cat << END >>  $ISSM_DIR/dailylog/info.log
 elapsed_run:   $(echo $ELAPSED_RUN)
 elapsed_total: $(echo $ELAPSED_TOTAL)
@@ -158,7 +158,7 @@
 #Send Report
 #Build html report {{{1
-cd $ISSM_TIER/dailylog/
+cd $ISSM_DIR/dailylog/
 sh ../scripts/report.sh
-ln -s $ISSM_TIER/dailylog/report.html $INIT_PATH
-echo "html report located in $ISSM_TIER/dailylog/report.html and $INIT_PATH/report.html"
+ln -s $ISSM_DIR/dailylog/report.html $INIT_PATH
+echo "html report located in $ISSM_DIR/dailylog/report.html and $INIT_PATH/report.html"
 #}}}
@@ -54,15 +54,15 @@
 #Prepare run
 #Windows hack for startup.m {{{1
-#windows environments: ISSM_TIER_WIN variable not correctly picked up when using 
-#the cron job. just get startup to take the ISSM_TIER variable as the pwd:
+#windows environments: ISSM_DIR_WIN variable not correctly picked up when using 
+#the cron job. just get startup to take the ISSM_DIR variable as the pwd:
 if [ "$OS" = "winxp32" ]
 then